netapp_ontap.resources.governance_aggregations API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.governance_aggregations`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class GovernanceAggregations (*args, **kwargs)`

  Allows interaction with GovernanceAggregations objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves aggregation data across all workspaces.

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class GovernanceAggregationsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the GovernanceAggregations object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `classifier_category_count: Size GET`

    Total number of classifier categories across all workspaces.

    Example: 4

  `classifier_matched_in_last30_days_count: Size GET`

    Number of classifiers matched in the last 30 days.

    Example: 4

  `data_collection_count: Size GET`

    Total number of data collections across all workspaces.

    Example: 7

  `data_container_count: Size GET`

    Total number of data containers across all workspaces.

    Example: 8

  `enabled_classifier_count: Size GET`

    Total number of enabled classifiers across all workspaces.

    Example: 6

  `enabled_guardrail_count: Size GET`

    Total number of enabled guardrails across all workspaces.

    Example: 3

  `guardrail_with_disabled_classifier_count: Size GET`

    Number of guardrails that have disabled classifiers.

    Example: 5

  `guardrail_workspace_count: Size GET`

    Number of workspaces with guardrails.

    Example: 2

  `impacted_entities_by_guardrails_count: Size GET`

    Total number of entities impacted by guardrails across all workspaces.

    Example: 2

  `non_guardrail_workspace_count: Size GET`

    Number of workspaces without guardrails.

    Example: 4

  `recent_workspaces: List[str] GET`

    The recent_workspaces field of the governance_aggregations.

  `scanned_content_size: Size GET`

    Total scanned content size across all workspaces.

    Example: 8776552

  `simulated_guardrail_count: Size GET`

    Number of guardrails that are in testing.

    Example: 2

  `workspace_count: Size GET`

    Total number of workspaces.

    Example: 2